diff --git a/.github/FUNDING.yml b/.github/FUNDING.yml
new file mode 100644
index 00000000..b4251f42
--- /dev/null
+++ b/.github/FUNDING.yml
@@ -0,0 +1 @@
+custom: https://boosty.to/qucs_s
diff --git a/.github/workflows/cmake.yml b/.github/workflows/cmake.yml
new file mode 100644
index 00000000..585655cb
--- /dev/null
+++ b/.github/workflows/cmake.yml
@@ -0,0 +1,44 @@
+name: CMake
+
+on:
+ push:
+ branches: [ "master" ]
+ pull_request:
+ branches: [ "master" ]
+
+env:
+ # Customize the CMake build type here (Release, Debug, RelWithDebInfo, etc.)
+ BUILD_TYPE: Release
+
+jobs:
+
+
+
+ build:
+ # The CMake configure and build commands are platform agnostic and should work equally well on Windows or Mac.
+ # You can convert this to a matrix build if you need cross-platform coverage.
+ # See: https://docs.github.com/en/free-pro-team@latest/actions/learn-github-actions/managing-complex-workflows#using-a-build-matrix
+ runs-on: ubuntu-latest
+
+ steps:
+ - uses: actions/checkout@v3
+
+ - name: InstallQt5
+ run: |
+ sudo apt-get update
+ sudo apt-get install -y qtbase5-dev qttools5-dev qtscript5-dev libqt5svg5-dev
+ - name: Configure CMake
+ # Configure CMake in a 'build' subdirectory. `CMAKE_BUILD_TYPE` is only required if you are using a single-configuration generator such as make.
+ # See https://cmake.org/cmake/help/latest/variable/CMAKE_BUILD_TYPE.html?highlight=cmake_build_type
+ run: cmake -B ${{github.workspace}}/build -DCMAKE_BUILD_TYPE=${{env.BUILD_TYPE}}
+
+ - name: Build
+ # Build your program with the given configuration
+ run: cmake --build ${{github.workspace}}/build --config ${{env.BUILD_TYPE}}
+
+ #- name: Test
+ # working-directory: ${{github.workspace}}/build
+ # Execute tests defined by the CMake configuration.
+ # See https://cmake.org/cmake/help/latest/manual/ctest.1.html for more detail
+ # run: ctest -C ${{env.BUILD_TYPE}}
+
diff --git a/NEWS.md b/NEWS.md
new file mode 100644
index 00000000..11b2cd0d
--- /dev/null
+++ b/NEWS.md
@@ -0,0 +1,62 @@
+# Qucs-S 0.0.24
+
+## New simulation types
+
+* Added S-parameter simulation using Ngspice and Xyce backends; Ngspice>=37 requiered #84, #79
+* Added FFT analysis with Ngspice backend #88
+
+## GUI improvements
+
+* Implemented dark desktop theme support #66
+* Implemented manual setting of the X-axis markers postion #92
+* Added separate setting for schematic and application font
+
+## Qt5 support
+
+* Removed QtScript dependency (thanks @Zergud) #77
+* Fixed Qt5.15 deprecation warnings #75
+
+## Component libraries
+
+* Added quartz crystal library (Crystal.lib); the quartz model is optimized for filter design;
+* Added TL431 device in Regulators library;
+
+## General bugfixes
+
+* Fixed crash on HB simulation with XYCE #28
+* Fixed empty path for working directory #86
+* Show error when schematic contains only DC simulation (no effect for Ngspice) #83
+* Fixed layout in arrow properties dialog #81
+* Fixed drag'n'drop operation from left dock to schematic
+* Fixed newlines in SPICE resitors #62
+* Fixed crash on Wayland #76
+
+## Documentation and examples
+
+* Added offline PDF tutorial; the link for old Qucs tutorial removed from Help menu #78
+* Added examples for new S-parameter and FFT simulations
+* Fixed distortion simulation example #83
+
+## Known issues
+
+* Parameter sweep doesn't work when using the Fourier simulation with XYCE backend #73
+* Netlister may produce duplicate .SUBCKT entry when using the same component from user and system library #82
+
+# Qucs-S 0.0.23
+
+## Qt5 support and new features
+
+* The Qucs-S application is now fully ported to Qt5 and could be compiled on modern Linux distributions; #72 #32
+* Added two new component libraries: BF998 and Tubes containing two-gate MOSFET and vacuum tubes (triodes and penthodes provided by @olegkapitonov ) models;
+* Windows binary switched to 64-bit build. The old 32-bit binaries are not provided anymore;
+* Ngspice is now the default simulation kernel on the first application start;
+* The Qucs-S doesn't use a shared settings file with Qucs anymore #71
+
+## General bugfixes
+
+* Fixed "Show last netlists" not showing SPICE netlist when SPICE engine is selected #41
+* Use system default sans serif font instead of "Helvetica", because "Helvetica" cannot be rendered correctly on some platforms;
+* Fixed .INCLUDE directive support with SpiceOpus #16
+* Partially fixed .FOUR simulation support for Xyce backend #73
+* Removed warning about experimental feature in the simulation dialog. Qucs-S is considered to be stable now;
+
diff --git a/NEWS b/NEWS_qucs
similarity index 100%
rename from NEWS
rename to NEWS_qucs
diff --git a/README.md b/README.md
index ed9e002c..f862c831 100644
--- a/README.md
+++ b/README.md
@@ -1,11 +1,11 @@
-## Description
+## Qucs-S: Quite universal circuit simulator with SPICE
-Qucs-S provides a fancy graphical user interfyce for a number of popular circuit simulation
-engines. Qucs-S contains schematic capture, visualization and component library. The following
+Qucs-S provides a fancy graphical user interface for a number of popular circuit simulation
+engines. Qucs-S contains libraries for schematic capture, visualization and components. The following
simulation kernels are supported:
* Ngspice (recommended)
-* Xyce
+* Xyce
* SpiceOpus
* Qucsator (non-spice)
@@ -13,21 +13,31 @@ simulation kernels are supported:
See the https://ra3xdh.github.io/ for more details. Qucs-S is based
on original Qucs code: https://github.com/Qucs/qucs
+## Donation
+
+Qucs-S accepts donation using Boosty platform: https://boosty.to/qucs_s
+
## Build instructions
-Use CMake to build Qucs-S. Install all necessary dependecies: GCC, Qt, and SPICE
-(optional). For Ubuntu launch the following command to install developement tools:
+Use CMake to build Qucs-S. Install all necessary dependencies: GCC, Qt, and SPICE
+(optional). Install `ngspice` that is not needed for build, but serves as the simulation kernel.
+
+### Dependencies
+
+#### Ubuntu
~~~
-sudo apt-get install build-essential git cmake qtbase5-dev qttools5-dev qtscript5-dev libqt5svg5-dev
+sudo apt-get install ngspice build-essential git cmake qtbase5-dev qttools5-dev qtscript5-dev libqt5svg5-dev
~~~
-Install `ngspice` that is not needed for build but serves as the simulation kernel.
+#### OpenSUSE Tumbleweed
~~~
-sudo apt-get install ngspice
+sudo zypper install ngspice git cmake libqt5-qtbase-devel libqt5-qttools-devel libqt5-qtscript-devel libqt5-qtsvg-devel
~~~
+### Compiling
+
Then clone this git repository and execute in the top directory:
~~~
@@ -39,10 +49,12 @@ make install
~~~
Where `/your_install_prefix/` is desired installation directory. Substitute any
-desire path (for example `$HOME/qucs-s`) here. You may omit this option and
-installation steps. Default installation directory will be `/usr/local` if
+desire path (for example `$HOME/qucs-s`) here. You may omit this option and
+installation steps. Default installation directory will be `/usr/local` if
`CMAKE_INSTALL_PREFIX` is not defined.
+### Running
+
Then run `qucs-s` executable to launch the application:
~~~
cd /your_installation prefix/bin
diff --git a/README_qucs b/README_qucs
index 9c57da42..df42509f 100644
--- a/README_qucs
+++ b/README_qucs
@@ -82,5 +82,5 @@ version might not even compile.
$ git clone http://git.code.sf.net/p/qucs/git qucs-git
Press 'Enter' when asked for a password. Run `sh bootstrap.sh' and
-`configure' with the appropriate options. Maintainance currently
+`configure' with the appropriate options. Maintenance currently
requires Autoconf version 2.57 and GNU automake 1.7.0.
diff --git a/RELEASE b/RELEASE
index d08fdca8..b5d7c689 100644
--- a/RELEASE
+++ b/RELEASE
@@ -30,7 +30,7 @@ Distribution process:
- Make sure INSTALL, THANKS and README files are up to date.
* Test build and packaging.
- - Maintainance currently requires the following software packages:
+ - Maintenance currently requires the following software packages:
+ Autoconf version 2.57 (at least)
+ GNU automake 1.7.0 (at least)
+ Qt installation >= version 4.6 (by Digia)
diff --git a/examples/external_interface/m-interface/asynchronous_boost_converter_example.m b/examples/external_interface/m-interface/asynchronous_boost_converter_example.m
index e7956781..725fea3b 100644
--- a/examples/external_interface/m-interface/asynchronous_boost_converter_example.m
+++ b/examples/external_interface/m-interface/asynchronous_boost_converter_example.m
@@ -8,7 +8,7 @@ tstart = 0;
n = 100;
tend = 5e-4;
-%% fixed-step synchonous solver test
+%% fixed-step synchronous solver test
clear qtr_async1
diff --git a/examples/external_interface/m-interface/synchronous_boost_converter_example.m b/examples/external_interface/m-interface/synchronous_boost_converter_example.m
index c2ad669b..5687b523 100644
--- a/examples/external_interface/m-interface/synchronous_boost_converter_example.m
+++ b/examples/external_interface/m-interface/synchronous_boost_converter_example.m
@@ -6,7 +6,7 @@ tstart = 0;
n = 2000;
tend = 5e-4;
-%% fixed-step synchonous solver test
+%% fixed-step synchronous solver test
clear qtr_sync1
diff --git a/examples/ngspice/BJT-noise.sch b/examples/ngspice/BJT-noise.sch
index 2d31719a..de767cbc 100644
--- a/examples/ngspice/BJT-noise.sch
+++ b/examples/ngspice/BJT-noise.sch
@@ -66,5 +66,5 @@
-
+
diff --git a/examples/ngspice/BJT.sch b/examples/ngspice/BJT.sch
index c21162fa..d7f14835 100644
--- a/examples/ngspice/BJT.sch
+++ b/examples/ngspice/BJT.sch
@@ -72,5 +72,5 @@
-
+
diff --git a/examples/ngspice/RFLumpComp/RFLumpedComponents.lib b/examples/ngspice/RFLumpComp/RFLumpedComponents.lib
index cb44b3b3..a90b6880 100644
--- a/examples/ngspice/RFLumpComp/RFLumpedComponents.lib
+++ b/examples/ngspice/RFLumpComp/RFLumpedComponents.lib
@@ -11,7 +11,7 @@ l1; Lead parasitic inductance (H); 1.5n
ls; Resistance serial inductance; 5n
l2; Lead parasitic inductance (H); 1.5n
Cp; Resistor serial parasitic capacitance; 0.35p
-Cpad; Resistor parallel parastic; 5p
+Cpad; Resistor parallel parasitic; 5p
Test examples: (1) Test_RATF_EquivalentCircuitD.sch
diff --git a/examples/qucsator/Amp_Two_Tone.sch b/examples/qucsator/Amp_Two_Tone.sch
index daaa381b..87395942 100755
--- a/examples/qucsator/Amp_Two_Tone.sch
+++ b/examples/qucsator/Amp_Two_Tone.sch
@@ -87,5 +87,5 @@
- 135 degrees).\n\nThe DUT output intercept can be determined by noting the ratio of the sidebands to the carrier and performing a simple calculation.\nExamining the above spectrum, the carriers are at +13.4 dBm and the sideband level is -11.5 dBm. The ratio is then sideband level\nminus carrier level or: (-11.5) - (+13.4) = -24.9 dB.\n\nThe ouput intercept point is calculated by: IP3out = sideband/carrier ratio + (2 times output level) or: (-24.9) + 2(+13.4) = +1.9 dBm. The\ninput intercept point is simply output intercept minus gain or: IP3in = IP3out - gain in dB. ">
+ 135 degrees).\n\nThe DUT output intercept can be determined by noting the ratio of the sidebands to the carrier and performing a simple calculation.\nExamining the above spectrum, the carriers are at +13.4 dBm and the sideband level is -11.5 dBm. The ratio is then sideband level\nminus carrier level or: (-11.5) - (+13.4) = -24.9 dB.\n\nThe output intercept point is calculated by: IP3out = sideband/carrier ratio + (2 times output level) or: (-24.9) + 2(+13.4) = +1.9 dBm. The\ninput intercept point is simply output intercept minus gain or: IP3in = IP3out - gain in dB. ">
diff --git a/examples/qucsator/bbv.sch b/examples/qucsator/bbv.sch
index 20d569a7..2d1c463e 100644
--- a/examples/qucsator/bbv.sch
+++ b/examples/qucsator/bbv.sch
@@ -90,5 +90,5 @@
-
+
diff --git a/examples/qucsator/notch.sch b/examples/qucsator/notch.sch
index 56df23c0..2ae7ccb2 100644
--- a/examples/qucsator/notch.sch
+++ b/examples/qucsator/notch.sch
@@ -58,6 +58,6 @@
-
+
diff --git a/library/AnalogueCM/RFind.ifs b/library/AnalogueCM/RFind.ifs
index f145d726..e5766061 100644
--- a/library/AnalogueCM/RFind.ifs
+++ b/library/AnalogueCM/RFind.ifs
@@ -122,7 +122,7 @@ Null_Allowed: no
PARAMETER_TABLE:
Parameter_Name: tnom
-Description: "Inductance parameter measurement temperature n Celcius."
+Description: "Inductance parameter measurement temperature n Celsius."
Data_Type: real
Default_Value: 26.58
Vector: no
diff --git a/library/MESFETs/curtice1.ifs b/library/MESFETs/curtice1.ifs
index 7873236f..7833c639 100644
--- a/library/MESFETs/curtice1.ifs
+++ b/library/MESFETs/curtice1.ifs
@@ -91,7 +91,7 @@ Null_Allowed: no
PARAMETER_TABLE:
Parameter_Name: rf
-Description: "Forwad bias slope resistance."
+Description: "Forward bias slope resistance."
Data_Type: real
Default_Value: 10.0
Limits: -
diff --git a/library/OpAmps.lib b/library/OpAmps.lib
index e476307b..eea94f0d 100644
--- a/library/OpAmps.lib
+++ b/library/OpAmps.lib
@@ -412,7 +412,7 @@ Sub:X1 _net0 _net1 _net2 _net3 _net4 gnd Type="ua741_ps_cir"
OPA27 macromodel (Modified Boyle model generated by PSPICE parts).
-Manufactuer: Texas Instruments.
+Manufacturer: Texas Instruments.
.Def:OpAmps_opa27_TI_ _net0 _net1 _net2 _net3 _net4
diff --git a/library/Transformers.lib b/library/Transformers.lib
index 45524a0c..19422fef 100644
--- a/library/Transformers.lib
+++ b/library/Transformers.lib
@@ -5,8 +5,8 @@
Author: Mike Brinson ; 24 Nov. 2015
A two winding transformer with fringing inductance and resistive losses.
-Lmo is the primary winding inductance with the secondary winding OPEN circut.
-Lmf is the primary winding inductance with the secondary winding SHORT circut.
+Lmo is the primary winding inductance with the secondary winding OPEN circuit.
+Lmf is the primary winding inductance with the secondary winding SHORT circuit.
Rp is the primary winding DC resistance.
Rs is the secondary winding DC resistance.
Np = number of turns in primary winding.
diff --git a/library/Transistors.lib b/library/Transistors.lib
index b398314b..9cd1575c 100644
--- a/library/Transistors.lib
+++ b/library/Transistors.lib
@@ -3456,7 +3456,7 @@ Added by Frans Schreuder
power NPN BJT TO-204
250Vce 16A 250W audio and
- linear appications
+ linear applications
<_BJT T_MJ15024_ 1 1530 540 8 -26 0 0 "npn" 0 "1e-09" 0 "1.41415" 0 "1.5" 0 "3.58072" 0 "5.80356" 0 "29.8965" 0 "281.892" 0 "1e-16" 0 "4" 0 "1e-16" 0 "2.99908" 0 "80.9237" 0 "1.00135" 0 "0.1" 0 "0.1" 0 "0.0571126" 0 "0.00042229" 0 "9.25367" 0 "6.19402e-9" 0 "0.4" 0 "0.457365" 0 "05e-10" 0 "0.95" 0 "0.344125" 0 "0.1" 0 "0" 0 "0.75" 0 "0.5" 0 "0.8" 0 "1e-08" 0 "1000" 0 "1.07131" 0 "0.743213" 0 "1e-07" 0 "26.85" 0 "0.0" 0 "1.0" 0 "1.0" 0 "0.0" 0 "1.0" 0 "1.0" 0 "0.0" 0>
@@ -3467,7 +3467,7 @@ Added by Frans Schreuder
power PNP BJT TO-204
250Vce 16A 250W audio and
- linear appications
+ linear applications
<_BJT T_MJ15024_ 1 1530 920 8 -26 1 0 "pnp" 0 "1e-09" 0 "1.32219" 0 "1.5" 0 "2.86343 " 0 "4.83687 " 0 "27.5881" 0 "275.881 " 0 "4.07413e-09 " 0 "3.50785" 0 "4.07413e-09" 0 "2.99735 " 0 "80.6168" 0 "0.777511" 0 "0.1" 0 "0.1" 0 "0.0620212 " 0 "0.000422878 " 0 "8.67339 " 0 "7.12267e-09 " 0 "0.4" 0 "0.461473" 0 "5e-10 " 0 "0.95" 0 "0.23" 0 "0.1" 0 "0" 0 "0.75" 0 "0.5" 0 "0.8" 0 "1e-08" 0 "1000" 0 "1.06865 " 0 "0.653882" 0 "1e-07 " 0 "26.85" 0 "0.0" 0 "1.0" 0 "1.0" 0 "0.0" 0 "1.0" 0 "1.0" 0 "0.0" 0>
diff --git a/library/Xyce_Digital_TTL_Technology.lib b/library/Xyce_Digital_TTL_Technology.lib
index 50e11c65..a0123067 100644
--- a/library/Xyce_Digital_TTL_Technology.lib
+++ b/library/Xyce_Digital_TTL_Technology.lib
@@ -12,7 +12,7 @@
* Basic TTL 5V positive supply.
*
* A copy of this model must be placed on
-* (a) a Xyce top level circuit schematic whith linear and standard TTL digital components only,
+* (a) a Xyce top level circuit schematic with linear and standard TTL digital components only,
* or on
* (b) a Xyce user defined subckt which contains linear and standard TTL digital components only.
*
diff --git a/qucs-activefilter/helpdialog.cpp b/qucs-activefilter/helpdialog.cpp
index c7d561f7..cb4ba157 100644
--- a/qucs-activefilter/helpdialog.cpp
+++ b/qucs-activefilter/helpdialog.cpp
@@ -40,7 +40,7 @@ HelpDialog::HelpDialog(QWidget *parent)
" and User defined transfer function are supported."
"To create a filter, simply enter all "
"parameters and press the big button at the "
- "bottom of the main window. Immediatly, the "
+ "bottom of the main window. Immediately, the "
"schematic of the filter is calculated and "
"put into the clipboard. Now go to Qucs, "
"open an empty schematic and press "
diff --git a/qucs-activefilter/qf_poly.cpp b/qucs-activefilter/qf_poly.cpp
index 7b1d0d04..bed9ed62 100644
--- a/qucs-activefilter/qf_poly.cpp
+++ b/qucs-activefilter/qf_poly.cpp
@@ -1052,7 +1052,7 @@ qf_double_t qf_poly::evalX2 (qf_double_t c) {
void qf_poly::disp (const char *name) {
if (rep == NONE) {
- std::cout << name << "(x) is not initalized.\n";
+ std::cout << name << "(x) is not initialized.\n";
return;
}
diff --git a/qucs-attenuator/qucsattenuator.cpp b/qucs-attenuator/qucsattenuator.cpp
index a0eab669..72d58f24 100644
--- a/qucs-attenuator/qucsattenuator.cpp
+++ b/qucs-attenuator/qucsattenuator.cpp
@@ -203,7 +203,7 @@ void QucsAttenuator::slotHelpIntro()
tr("QucsAttenuator is an attenuator synthesis program. "
"To create a attenuator, simply enter all "
"the input parameters and press the calculation button. "
- "Immediatly, the "
+ "Immediately, the "
"schematic of the attenuator is calculated and "
"put into the clipboard. Now go to Qucs, "
"open an schematic and press "
diff --git a/qucs-filter/filter.cpp b/qucs-filter/filter.cpp
index 9f38860b..a584177a 100644
--- a/qucs-filter/filter.cpp
+++ b/qucs-filter/filter.cpp
@@ -244,7 +244,7 @@ double Filter::ChebyshevValue(int No, int Order, double Ripple)
a = sin(0.5 / double(Order) * pi);
gk = a / Ripple;
- for(i=1; i<=No; i++) { // coefficients are defined recursivly
+ for(i=1; i<=No; i++) { // coefficients are defined recursively
ak = a;
a = sin(double(2 * i + 1) / double(2 * Order) * pi);
b = sin(double(i) * pi / double(Order));
diff --git a/qucs-filter/helpdialog.cpp b/qucs-filter/helpdialog.cpp
index a2d58c91..3969f67a 100644
--- a/qucs-filter/helpdialog.cpp
+++ b/qucs-filter/helpdialog.cpp
@@ -38,7 +38,7 @@ HelpDialog::HelpDialog(QWidget *parent)
QString s(tr("QucsFilter is a filter synthesis program. "
"To create a filter, simply enter all "
"parameters and press the big button at the "
- "bottom of the main window. Immediatly, the "
+ "bottom of the main window. Immediately, the "
"schematic of the filter is calculated and "
"put into the clipboard. Now go to Qucs, "
"open an empty schematic and press "
diff --git a/qucs-filter/qf_filter.cpp b/qucs-filter/qf_filter.cpp
index 1f35e6b3..3ee6edc3 100644
--- a/qucs-filter/qf_filter.cpp
+++ b/qucs-filter/qf_filter.cpp
@@ -348,7 +348,7 @@ std::string qf_filter::to_qucs (void) {
res << "10";
res << " 0 0";
- // value of commponent
+ // value of component
res << " \"" << num2str(Comp[b].val).c_str();
switch (Comp[b].comp) {
case CAP: res << "F"; break;
diff --git a/qucs/components/CMakeLists.txt b/qucs/components/CMakeLists.txt
index 52cc9e4e..5042cd87 100644
--- a/qucs/components/CMakeLists.txt
+++ b/qucs/components/CMakeLists.txt
@@ -1,4 +1,4 @@
-# qucs/componenets library
+# qucs/components library
INCLUDE_DIRECTORIES( ${CMAKE_SOURCE_DIR}
${CMAKE_CURRENT_SOURCE_DIR} )
diff --git a/qucs/components/EKV26MOS.cpp b/qucs/components/EKV26MOS.cpp
index 40445ea6..25a5a40d 100644
--- a/qucs/components/EKV26MOS.cpp
+++ b/qucs/components/EKV26MOS.cpp
@@ -117,7 +117,7 @@ EKV26MOS::EKV26MOS()
Props.append (new Property ("Af", "1.0", false,
QObject::tr ("flicker noise exponent")));
Props.append (new Property ("Avto", "0.0", false,
- QObject::tr ("area related theshold voltage mismatch parameter")
+ QObject::tr ("area related threshold voltage mismatch parameter")
+" ("+QObject::tr ("V*m")+")"));
Props.append (new Property ("Akp", "0.0", false,
QObject::tr ("area related gain mismatch parameter")
diff --git a/qucs/components/MESFET.cpp b/qucs/components/MESFET.cpp
index 3e77dc85..06abaaa2 100644
--- a/qucs/components/MESFET.cpp
+++ b/qucs/components/MESFET.cpp
@@ -130,7 +130,7 @@ MESFET::MESFET()
QObject::tr ("source resistance temperature coefficient")
+" ("+QObject::tr ("1/Celsius")+")"));
Props.append (new Property ("Ibv", "1e-3", false,
- QObject::tr ("gate reverse breakdown currrent")
+ QObject::tr ("gate reverse breakdown current")
+" ("+QObject::tr ("A")+")"));
Props.append (new Property ("Rf", "10", false,
QObject::tr ("forward bias slope resistance")
diff --git a/qucs/components/bjt.cpp b/qucs/components/bjt.cpp
index ae9e582d..d3de48c3 100644
--- a/qucs/components/bjt.cpp
+++ b/qucs/components/bjt.cpp
@@ -54,7 +54,7 @@ QString BJT::spice_netlist(bool)
QStringList spice_incompat,spice_tr;
spice_incompat<<"Type"<<"Area"<<"Temp"<<"Ffe"<<"Kb"<<"Ab"<<"Fb"; // spice-incompatible parameters
- spice_tr.clear(); // parameters that need convertion of names
+ spice_tr.clear(); // parameters that need conversion of names
QString par_str = form_spice_param_list(spice_incompat,spice_tr);
diff --git a/qucs/components/components.h b/qucs/components/components.h
index c51b5ca7..9f1e0604 100644
--- a/qucs/components/components.h
+++ b/qucs/components/components.h
@@ -186,7 +186,7 @@
#include "etr_sim.h"
#include "ecvs.h"
-// Verilog-A dynamicaly loaded component
+// Verilog-A dynamically loaded component
#include "vacomponent.h"
#include "bsim3v34nMOS.h"
diff --git a/qucs/components/d_flipflop.cpp b/qucs/components/d_flipflop.cpp
index f74ed63d..f37d50fd 100644
--- a/qucs/components/d_flipflop.cpp
+++ b/qucs/components/d_flipflop.cpp
@@ -21,7 +21,7 @@
D_FlipFlop::D_FlipFlop()
{
Type = isDigitalComponent;
- Description = QObject::tr("D flip flop with asynchron reset");
+ Description = QObject::tr("D flip flop with asynchronous reset");
Props.append(new Property("t", "0", false, QObject::tr("delay time")));
diff --git a/qucs/components/diode.cpp b/qucs/components/diode.cpp
index fcbfe82c..ae900d00 100644
--- a/qucs/components/diode.cpp
+++ b/qucs/components/diode.cpp
@@ -112,7 +112,7 @@ QString Diode::spice_netlist(bool isXyce)
QStringList spice_incompat,spice_tr;
if (isXyce) {
- spice_tr<<"Tbv"<<"Tbv1"<<"Trs"<<"Trs1"; // parameters that need convertion of names
+ spice_tr<<"Tbv"<<"Tbv1"<<"Trs"<<"Trs1"; // parameters that need conversion of names
spice_incompat<<"Ttt1"<<"Ttt2"<<"Tm1"<<"Tm2"<<"Cp"<<"Isr"
<<"Nr"<<"Ffe"<<"Temp"<<"Area"<<"Symbol"; // spice-incompatible parameters
} else {
diff --git a/qucs/components/eqndefined.cpp b/qucs/components/eqndefined.cpp
index c0ed1279..2711d125 100644
--- a/qucs/components/eqndefined.cpp
+++ b/qucs/components/eqndefined.cpp
@@ -195,7 +195,7 @@ QString EqnDefined::va_code()
}
/*!
- * \brief EqnDefined::subsVoltages Substitute volatges in spice Notation in token list
+ * \brief EqnDefined::subsVoltages Substitute voltages in spice Notation in token list
* \param[in/out] tokens Token list. Should be obtained from spicecompat::splitEqn().
* This list is modified.
* \param[in] Nbranch Number of branched of EDD
diff --git a/qucs/components/equation.cpp b/qucs/components/equation.cpp
index cb42f93b..87fc6a05 100644
--- a/qucs/components/equation.cpp
+++ b/qucs/components/equation.cpp
@@ -116,7 +116,7 @@ QString Equation::getVAExpressions()
}
/*!
- * \brief Equation::getExpression Extract equations that don't contain simualtion variables
+ * \brief Equation::getExpression Extract equations that don't contain simulation variables
* (voltages/cureents) in .PARAM section of spice netlist
* \param isXyce True if Xyce is used.
* \return .PARAM section of spice netlist as a single string.
diff --git a/qucs/components/jfet.cpp b/qucs/components/jfet.cpp
index 35e3f6d4..0883c49d 100644
--- a/qucs/components/jfet.cpp
+++ b/qucs/components/jfet.cpp
@@ -109,11 +109,11 @@ QString JFET::spice_netlist(bool isXyce)
spice_incompat<<"Type"<<"Area"<<"Temp"<<"Ffe"<<"N"
<<"Isr"<<"Nr"<<"M"<<"Xti"<<"Betatce"<<"Vt0tc";
// spice-incompatible parameters
- spice_tr<<"Vt0"<<"VtO"; // parameters that need convertion of names
+ spice_tr<<"Vt0"<<"VtO"; // parameters that need conversion of names
} else {
spice_incompat<<"Type"<<"Area"<<"Temp"<<"Ffe"<<"N"<<"Isr"<<"Nr"<<"M"<<"Xti"<<"Betatce";
// spice-incompatible parameters
- spice_tr<<"Vt0tc"<<"Tcv"; // parameters that need convertion of names
+ spice_tr<<"Vt0tc"<<"Tcv"; // parameters that need conversion of names
}
diff --git a/qucs/components/jk_flipflop.cpp b/qucs/components/jk_flipflop.cpp
index 4c434e6b..a8babb6a 100644
--- a/qucs/components/jk_flipflop.cpp
+++ b/qucs/components/jk_flipflop.cpp
@@ -23,7 +23,7 @@
JK_FlipFlop::JK_FlipFlop()
{
Type = isDigitalComponent;
- Description = QObject::tr("JK flip flop with asynchron set and reset");
+ Description = QObject::tr("JK flip flop with asynchronous set and reset");
Props.append(new Property("t", "0", false, QObject::tr("delay time")));
diff --git a/qucs/components/mosfet.cpp b/qucs/components/mosfet.cpp
index 5cd6e11f..a95bc554 100644
--- a/qucs/components/mosfet.cpp
+++ b/qucs/components/mosfet.cpp
@@ -155,7 +155,7 @@ QString MOSFET::spice_netlist(bool isXyce)
<<"Rg"<<"N"<<"Tt"<<"Nrd"<<"Nrs"<<"Ffe";
// spice-incompatible parameters
if (isXyce) {
- spice_tr<<"Vt0"<<"VtO"; // parameters that need convertion of names
+ spice_tr<<"Vt0"<<"VtO"; // parameters that need conversion of names
} else {
spice_tr.clear();
}
diff --git a/qucs/components/mosfet_sub.cpp b/qucs/components/mosfet_sub.cpp
index 38b63f9d..4623047f 100644
--- a/qucs/components/mosfet_sub.cpp
+++ b/qucs/components/mosfet_sub.cpp
@@ -162,7 +162,7 @@ QString MOSFET_sub::spice_netlist(bool isXyce)
<<"Rg"<<"N"<<"Tt"<<"Nrd"<<"Nrs"<<"Ffe";
// spice-incompatible parameters
if (isXyce) {
- spice_tr<<"Vt0"<<"VtO"; // parameters that need convertion of names
+ spice_tr<<"Vt0"<<"VtO"; // parameters that need conversion of names
} else {
spice_tr.clear();
}
diff --git a/qucs/components/optimizedialog.cpp b/qucs/components/optimizedialog.cpp
index 64652362..9ca69664 100644
--- a/qucs/components/optimizedialog.cpp
+++ b/qucs/components/optimizedialog.cpp
@@ -61,7 +61,7 @@ OptimizeDialog::OptimizeDialog(Optimize_Sim *c_, Schematic *d_)
numVal = new QDoubleValidator(this);
intVal = new QIntValidator(this);
- all = new QVBoxLayout(); // to provide the neccessary size
+ all = new QVBoxLayout(); // to provide the necessary size
QTabWidget *t = new QTabWidget();
all->addWidget(t);
this->setLayout(all);
diff --git a/qucs/components/spicedialog.cpp b/qucs/components/spicedialog.cpp
index 39ecbcaa..b0d6e0ce 100644
--- a/qucs/components/spicedialog.cpp
+++ b/qucs/components/spicedialog.cpp
@@ -49,7 +49,7 @@ SpiceDialog::SpiceDialog(QucsApp* App_, SpiceFile *c, Schematic *d)
Comp = c;
Doc = d;
- all = new QVBoxLayout(); // to provide neccessary size
+ all = new QVBoxLayout(); // to provide necessary size
this->setLayout(all);
QWidget *myParent = this;
diff --git a/qucs/diagrams/diagram.cpp b/qucs/diagrams/diagram.cpp
index 9cdddacc..376b5571 100644
--- a/qucs/diagrams/diagram.cpp
+++ b/qucs/diagrams/diagram.cpp
@@ -361,7 +361,7 @@ void Diagram::rectClip(Graph::iterator &p) const
int code1 = regionCode(x_1, y_1);
int code2 = regionCode(x_2, y_2);
- if((code1 | code2) == 0) return; // line completly inside ?
+ if((code1 | code2) == 0) return; // line completely inside ?
if(code1 != 0) if((p-3)->isPt()) {
p++;
@@ -378,7 +378,7 @@ void Diagram::rectClip(Graph::iterator &p) const
for(;;) {
- if((code1 | code2) == 0) break; // line completly inside ?
+ if((code1 | code2) == 0) break; // line completely inside ?
if(code1) code = code1;
else code = code2;
@@ -439,7 +439,7 @@ void Diagram::clip(Graph::iterator &p) const
float dt2 = dt1 - x_2*x_2 - y_2*y_2;
dt1 -= x_1*x_1 + y_1*y_1;
- if(dt1 >= 0.0) if(dt2 >= 0.0) return; // line completly inside ?
+ if(dt1 >= 0.0) if(dt2 >= 0.0) return; // line completely inside ?
if(dt1 < 0.0) if((p-3)->isPt()) { // is there already a line end flag ?
p++;
@@ -713,7 +713,7 @@ void Diagram::loadGraphData(const QString& defaultDataSet)
xAxis.min = xmin; yAxis.min = ymin; zAxis.min = zmin;
xAxis.max = xmax; yAxis.max = ymax; zAxis.max = zmax;
- return; // -> no update neccessary
+ return; // -> no update necessary
}
if(xAxis.min > xAxis.max)
@@ -832,7 +832,7 @@ int Graph::loadDatFile(const QString& fileName)
Info.setFile(file);
if(g->lastLoaded.isValid())
if(g->lastLoaded > Info.lastModified())
- return 1; // dataset unchanged -> no update neccessary
+ return 1; // dataset unchanged -> no update necessary
g->countY = 0;
g->mutable_axes().clear(); // HACK
@@ -902,7 +902,7 @@ int Graph::loadDatFile(const QString& fileName)
tmp = Line.section(' ', pos, pos);
while(!tmp.isEmpty()) {
if (hasExplIndep)g->mutable_axes().push_back(new DataX(ExplIndep));
- else g->mutable_axes().push_back(new DataX(tmp)); // name of independet variable
+ else g->mutable_axes().push_back(new DataX(tmp)); // name of independent variable
pos++;
tmp = Line.section(' ', pos, pos);
}
@@ -1005,7 +1005,7 @@ if(Variable.right(3) != ".X ") { // not "digital"
}
}
-#if 0 // this is not location curce code.
+#if 0 // this is not location curve code.
else { // location curve needs different treatment
if(std::isfinite(x)) {
if(x > xAxis.max) xAxis.max = x;
@@ -1758,7 +1758,7 @@ if(Axis->autoScale) {
numGrids += corr; // correct rounding faults
- // upper y boundery ...........................
+ // upper y boundary ...........................
zD = fabs(fmod(Axis->up, GridStep));// expand grid to upper diagram edge ?
GridNum = zD/GridStep;
if((1.0-GridNum) < 1e-10) GridNum = 0.0; // fix rounding errors
@@ -1771,7 +1771,7 @@ if(Axis->autoScale) {
Axis->up += 0.3*GridStep; // beauty correction
- // lower y boundery ...........................
+ // lower y boundary ...........................
zD = fabs(fmod(Axis->low, GridStep));// expand grid to lower diagram edge ?
GridNum = zD/GridStep;
if((1.0-GridNum) < 1e-10) zD = GridNum = 0.0; // fix rounding errors
diff --git a/qucs/diagrams/diagram.h b/qucs/diagrams/diagram.h
index f83b5225..e13c7df8 100644
--- a/qucs/diagrams/diagram.h
+++ b/qucs/diagrams/diagram.h
@@ -32,7 +32,7 @@
#define INVALID_STR QObject::tr(" ")
// ------------------------------------------------------------
-// Enlarge memory block if neccessary.
+// Enlarge memory block if necessary.
#define FIT_MEMORY_SIZE \
if(p >= p_end) { \
int pos = p - g->begin(); \
diff --git a/qucs/diagrams/diagramdialog.cpp b/qucs/diagrams/diagramdialog.cpp
index aa877d25..294f68f3 100644
--- a/qucs/diagrams/diagramdialog.cpp
+++ b/qucs/diagrams/diagramdialog.cpp
@@ -155,7 +155,7 @@ DiagramDialog::DiagramDialog(Diagram *d, QWidget *parent, Graph *currentGraph)
}
- all = new QVBoxLayout(this); // to provide neccessary size
+ all = new QVBoxLayout(this); // to provide necessary size
QTabWidget *t = new QTabWidget();
all->addWidget(t);
diff --git a/qucs/diagrams/graph.cpp b/qucs/diagrams/graph.cpp
index eb6355db..0ee5a9b4 100644
--- a/qucs/diagrams/graph.cpp
+++ b/qucs/diagrams/graph.cpp
@@ -276,7 +276,7 @@ std::pair Graph::findSample(std::vector& VarPos) const
for(unsigned ii=0; (pD=axis(ii)); ++ii) {
double* pp = pD->Points;
double v = VarPos[nVarPos];
- for(unsigned i=pD->count; i>1; i--) { // find appropiate marker position
+ for(unsigned i=pD->count; i>1; i--) { // find appropriate marker position
if(fabs(v-(*pp)) < fabs(v-(*(pp+1)))) break;
pp++;
n += m;
diff --git a/qucs/diagrams/rect3ddiagram.cpp b/qucs/diagrams/rect3ddiagram.cpp
index b0d16e71..8726b3c0 100644
--- a/qucs/diagrams/rect3ddiagram.cpp
+++ b/qucs/diagrams/rect3ddiagram.cpp
@@ -251,7 +251,7 @@ bool Rect3DDiagram::isHidden(int x, int y, tBound *Bounds, char *zBuffer)
}
// --------------------------------------------------------------
-// Enlarge memory block if neccessary.
+// Enlarge memory block if necessary.
void Rect3DDiagram::enlargeMemoryBlock(tPoint3D* &MemEnd)
{
if(pMem >= MemEnd) {
@@ -341,7 +341,7 @@ void Rect3DDiagram::calcLine(tPoint3D* &p, tPoint3D* &MemEnd,
pMem++;
Pos_ = p - Mem;
- // Enlarge memory block if neccessary.
+ // Enlarge memory block if necessary.
enlargeMemoryBlock(MemEnd); // this may make "p" invalid (realloc)
p = Mem + Pos_; // rebuild "p"
}
@@ -472,7 +472,7 @@ void Rect3DDiagram::removeHiddenLines(char *zBuffer, tBound *Bounds)
// ..........................................
// Calculate the z-coordinate of all polygons by building the
// sum of the z-coordinates of all of its 4 corners.
- // After this, each point represents one polygon. The unneccessary
+ // After this, each point represents one polygon. The unnecessary
// points are filled with "-FLTMAX".
zp = zp_tmp;
// "dx" and "dy" are still unchanged !
diff --git a/qucs/dialogs/labeldialog.cpp b/qucs/dialogs/labeldialog.cpp
index b5fdd63c..c115047f 100644
--- a/qucs/dialogs/labeldialog.cpp
+++ b/qucs/dialogs/labeldialog.cpp
@@ -117,7 +117,7 @@ void LabelDialog::slotOk()
QMessageBox::warning(this,tr("SPICE checker"),
QString(tr("Node name \"%1\" is Nutmeg reserved keyword!\n"
"Please select another node name!\n"
- "Node name will not be chenged.")).arg(nod),
+ "Node name will not be changed.")).arg(nod),
QMessageBox::Ok);
slotCancel();
return;
diff --git a/qucs/dialogs/librarydialog.cpp b/qucs/dialogs/librarydialog.cpp
index 43c82f0f..e0cd1ff8 100644
--- a/qucs/dialogs/librarydialog.cpp
+++ b/qucs/dialogs/librarydialog.cpp
@@ -171,7 +171,7 @@ LibraryDialog::LibraryDialog(QWidget *parent)
createButt->setDisabled(true);
- // stacked 2 - show error / sucess message
+ // stacked 2 - show error / success message
// ...........................................................
QWidget *msg = new QWidget();
stackedWidgets->addWidget(msg);
@@ -291,7 +291,7 @@ void LibraryDialog::slotCreateNext()
}
}
else {
- // save whitout description
+ // save without description
emit slotSave();
}
}
diff --git a/qucs/dialogs/qucssettingsdialog.cpp b/qucs/dialogs/qucssettingsdialog.cpp
index 99ab5c3d..2df2ca61 100644
--- a/qucs/dialogs/qucssettingsdialog.cpp
+++ b/qucs/dialogs/qucssettingsdialog.cpp
@@ -144,13 +144,13 @@ QucsSettingsDialog::QucsSettingsDialog(QucsApp *parent)
appSettingsGrid->addWidget(new QLabel(tr("Draw diagrams with anti-aliasing feature:")));
checkAntiAliasing = new QCheckBox(appSettingsTab);
- checkAntiAliasing->setToolTip(tr("Use anti-aliasing for graphs for a smoother appereance."));
+ checkAntiAliasing->setToolTip(tr("Use anti-aliasing for graphs for a smoother appearance."));
appSettingsGrid->addWidget(checkAntiAliasing,9,1);
checkAntiAliasing->setChecked(QucsSettings.GraphAntiAliasing);
appSettingsGrid->addWidget(new QLabel(tr("Draw text with anti-aliasing feature:")));
checkTextAntiAliasing = new QCheckBox(appSettingsTab);
- checkTextAntiAliasing->setToolTip(tr("Use anti-aliasing for text for a smoother appereance."));
+ checkTextAntiAliasing->setToolTip(tr("Use anti-aliasing for text for a smoother appearance."));
appSettingsGrid->addWidget(checkTextAntiAliasing,10,1);
checkTextAntiAliasing->setChecked(QucsSettings.TextAntiAliasing);
diff --git a/qucs/dialogs/simmessage.cpp b/qucs/dialogs/simmessage.cpp
index 04d335dc..e62479f8 100644
--- a/qucs/dialogs/simmessage.cpp
+++ b/qucs/dialogs/simmessage.cpp
@@ -219,7 +219,7 @@ void SimMessage::nextSPICE()
return;
}
// FIXME #warning SPICE section below not being covered?
- qDebug() << "goin thru SPICE branch on simmmessage.cpp";
+ qDebug() << "going thru SPICE branch on simmmessage.cpp";
if(Line.left(5) == "SPICE") {
if(Line.at(5) != 'o') insertSim = true;
else insertSim = false;
@@ -485,9 +485,9 @@ void SimMessage::startSimulator()
* the schematic,it might be the case that the user loaded the icons,
* but did not compiled the module. Qucsator will not find the library.
*
- * Check if used symbols have corresponing lib before running
+ * Check if used symbols have corresponding lib before running
* Qucsator? Need to search on the netlis.txt? Is there other data
- * structure containig the netlist?
+ * structure containing the netlist?
*
*/
QStringList usedComponents;
@@ -509,12 +509,12 @@ void SimMessage::startSimulator()
if (! usedComponents.isEmpty()) {
- /// \todo remvoe the command line arguments? use only netlist annotation?
+ /// \todo remove the command line arguments? use only netlist annotation?
//Arguments << "-p" << QucsSettings.QucsWorkDir.absolutePath()
// << "-m" << usedComponents;
//qDebug() << "Command :" << Program << Arguments.join(" ");
- /// Anotate netlist with Verilog-A dynamic path and module names
+ /// Annotate netlist with Verilog-A dynamic path and module names
///
if (!NetlistFile.open(QFile::Append | QFile::Text))
QMessageBox::critical(this, tr("Error"), tr("Cannot read netlist!"));
diff --git a/qucs/dialogs/textboxdialog.cpp b/qucs/dialogs/textboxdialog.cpp
index 735a4d2b..e4d6a5c1 100644
--- a/qucs/dialogs/textboxdialog.cpp
+++ b/qucs/dialogs/textboxdialog.cpp
@@ -64,7 +64,7 @@ TextBoxDialog::TextBoxDialog(const char* window_title, Component *pc, QWidget *p
}
/*!
- * \brief CustomSimDialog::slotApply Aplly changes of component properties.
+ * \brief CustomSimDialog::slotApply Apply changes of component properties.
*/
void TextBoxDialog::slotApply()
{
@@ -81,7 +81,7 @@ void TextBoxDialog::slotOK()
}
/*!
- * \brief CustomSimDialog::slotCancel Close dialog without apply chages.
+ * \brief CustomSimDialog::slotCancel Close dialog without applying changes.
*/
void TextBoxDialog::slotCancel()
{
diff --git a/qucs/extsimkernels/abstractspicekernel.cpp b/qucs/extsimkernels/abstractspicekernel.cpp
index d6cdb02b..050940a8 100644
--- a/qucs/extsimkernels/abstractspicekernel.cpp
+++ b/qucs/extsimkernels/abstractspicekernel.cpp
@@ -40,7 +40,7 @@
/*!
* \brief AbstractSpiceKernel::AbstractSpiceKernel class constructor
- * \param sch_ Schematic that schould be simualted with Spice-comaptibele
+ * \param sch_ Schematic that should be simulated with Spice-compatible
* simulator
* \param parent Parent object
*/
@@ -308,8 +308,8 @@ void AbstractSpiceKernel::slotSimulate()
* or Complex) from output.
* \param ngspice_file Spice output file name
* \param sim_points 2D array in which simulation points should be extracted
- * \param var_list This list is filled by simualtion variables. There is a list of dependent
- * and independent varibales. An independent variable is the first in list.
+ * \param var_list This list is filled by simulation variables. There is a list of dependent
+ * and independent variables. An independent variable is the first in list.
* \param isComplex Type of variables. True if complex. False if real.
*/
void AbstractSpiceKernel::parseNgSpiceSimOutput(QString ngspice_file,QList< QList > &sim_points,QStringList &var_list, bool &isComplex)
@@ -387,8 +387,8 @@ void AbstractSpiceKernel::parseNgSpiceSimOutput(QString ngspice_file,QList< QLis
* \brief AbstractSpiceKernel::parseHBOutput Parse Xyce Harmonic balance (HB) simulation output.
* \param ngspice_file Spice output file name
* \param sim_points 2D array in which simulation points should be extracted
- * \param var_list This list is filled by simualtion variables. There is a list of dependent
- * varibales. Independent hbfrequency variable is always the first in this list.
+ * \param var_list This list is filled by simulation variables. There is a list of dependent
+ * variables. Independent hbfrequency variable is always the first in this list.
* \param hasParSweep[out] Set to true if dataset contains parameter sweep output.
*/
void AbstractSpiceKernel::parseHBOutput(QString ngspice_file, QList > &sim_points,
@@ -439,8 +439,8 @@ void AbstractSpiceKernel::parseHBOutput(QString ngspice_file, QList > &sim_points,
QStringList &var_list)
@@ -507,8 +507,8 @@ void AbstractSpiceKernel::parseFourierOutput(QString ngspice_file, QList > &sim_points,
@@ -581,12 +581,12 @@ void AbstractSpiceKernel::parsePZOutput(QString ngspice_file, QList > &sim_points,
QStringList &var_list)
@@ -696,8 +696,8 @@ void AbstractSpiceKernel::parseDC_OPoutputXY(QString xyce_file)
* \param ngspice_file Spice output file name
* \param sim_points 2D array in which simulation points should be extracted. All simulation
* points from all sweep variable steps are extracted in a single array
- * \param var_list This list is filled by simualtion variables. There is a list of dependent
- * and independent varibales. An independent variable is the first in list.
+ * \param var_list This list is filled by simulation variables. There is a list of dependent
+ * and independent variables. An independent variable is the first in list.
* \param isComplex Type of variables. True if complex. False if real.
*/
void AbstractSpiceKernel::parseSTEPOutput(QString ngspice_file,
@@ -846,8 +846,8 @@ bool AbstractSpiceKernel::extractASCIISamples(QString &lin, QTextStream &ngsp_da
* \brief AbstractSpiceKernel::parseXYCESTDOutput
* \param std_file[in] XYCE STD output file name
* \param sim_points[out] 2D array in which simulation points should be extracted
- * \param var_list[out] This list is filled by simualtion variables. There is a list of dependent
- * and independent varibales. An independent variable is the first in list.
+ * \param var_list[out] This list is filled by simulation variables. There is a list of dependent
+ * and independent variables. An independent variable is the first in list.
* \param isComplex[out] Type of variables. True if complex. False if real.
*/
void AbstractSpiceKernel::parseXYCESTDOutput(QString std_file, QList > &sim_points,
@@ -1162,7 +1162,7 @@ void AbstractSpiceKernel::convertToQucsData(const QString &qucs_dataset)
default: break;
}
}
- if (var_list.isEmpty()) continue; // notning to convert
+ if (var_list.isEmpty()) continue; // nothing to convert
normalizeVarsNames(var_list);
QString indep = var_list.first();
diff --git a/qucs/extsimkernels/customsimdialog.cpp b/qucs/extsimkernels/customsimdialog.cpp
index 805075f5..fd60c3bb 100644
--- a/qucs/extsimkernels/customsimdialog.cpp
+++ b/qucs/extsimkernels/customsimdialog.cpp
@@ -98,7 +98,7 @@ CustomSimDialog::CustomSimDialog(SpiceCustomSim *pc, Schematic *sch, QWidget *pa
}
/*!
- * \brief CustomSimDialog::slotApply Aplly changes of component properties.
+ * \brief CustomSimDialog::slotApply Apply changes of component properties.
*/
void CustomSimDialog::slotApply()
{
@@ -117,7 +117,7 @@ void CustomSimDialog::slotOK()
}
/*!
- * \brief CustomSimDialog::slotCancel Close dialog without apply chages.
+ * \brief CustomSimDialog::slotCancel Close dialog without applying changes.
*/
void CustomSimDialog::slotCancel()
{
diff --git a/qucs/extsimkernels/customsimdialog.h b/qucs/extsimkernels/customsimdialog.h
index a3b773c6..df65f2d6 100644
--- a/qucs/extsimkernels/customsimdialog.h
+++ b/qucs/extsimkernels/customsimdialog.h
@@ -33,7 +33,7 @@
/*!
* \brief The CustomSimDialog class is responsible for editing properties
- * of Ngspice Custom Simualtion component. You can edit multiline
+ * of Ngspice Custom Simulation component. You can edit multiline
* component properties with it.
*/
class CustomSimDialog : public QDialog
diff --git a/qucs/extsimkernels/externsimdialog.cpp b/qucs/extsimkernels/externsimdialog.cpp
index 99e59034..38a6df53 100644
--- a/qucs/extsimkernels/externsimdialog.cpp
+++ b/qucs/extsimkernels/externsimdialog.cpp
@@ -228,7 +228,7 @@ void ExternSimDialog::slotNgspiceStartError(QProcess::ProcessError err)
break;
case QProcess::Crashed : msg = tr("Simulator crashed!");
break;
- default : msg = tr("Simualtor error!");
+ default : msg = tr("Simulator error!");
}
QMessageBox::critical(this,tr("Simulate with SPICE"),msg,QMessageBox::Ok);
diff --git a/qucs/extsimkernels/ngspice.cpp b/qucs/extsimkernels/ngspice.cpp
index 6109cb9c..1f5fec63 100644
--- a/qucs/extsimkernels/ngspice.cpp
+++ b/qucs/extsimkernels/ngspice.cpp
@@ -38,7 +38,7 @@
/*!
* \brief Ngspice::Ngspice Class constructor
- * \param sch_ Schematic that need to be simualted with Ngspice.
+ * \param sch_ Schematic that need to be simulated with Ngspice.
* \param parent Parent object
*/
Ngspice::Ngspice(Schematic *sch_, QObject *parent) :
@@ -73,7 +73,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
if (DC_OP_only) {
stream<<".control\n" // Execute only DC OP analysis
- <<"set filetype=ascii\n" // Ingnore all other simulations
+ <<"set filetype=ascii\n" // Ignore all other simulations
<<"op\n"
<<"print all > spice4qucs.cir.dc_op\n"
<<"destroy all\n"
@@ -426,7 +426,7 @@ QString Ngspice::getParentSWPscript(Component *pc_swp, QString sim, bool before,
}
/*!
- * \brief Ngspice::slotSimulate Create netlist and execute Ngspice simualtor. Netlist
+ * \brief Ngspice::slotSimulate Create netlist and execute Ngspice simulator. Netlist
* is saved at $HOME/.qucs/spice4qucs/spice4qucs.cir
*/
void Ngspice::slotSimulate()
@@ -575,7 +575,7 @@ bool Ngspice::findMathFuncInc(QString &mathf_inc)
}
/*!
- * \brief Ngspice::slotProcessOutput Process Ngspice output and report completetion
+ * \brief Ngspice::slotProcessOutput Process Ngspice output and report completion
* percentage.
*/
void Ngspice::slotProcessOutput()
@@ -610,6 +610,12 @@ void Ngspice::SaveNetlist(QString filename)
createNetlist(stream,num,sims,vars,output_files);
spice_file.close();
}
+ else
+ {
+ QString msg=QString("Tried to save netlist \nin %1\n(could not open for writing!)").arg(filename);
+ QString final_msg=QString("%1\n This could be an error in the QSettings settings file\n(usually in ~/.config/qucs/qucs_s.conf)\nThe value for S4Q_workdir (default:/spice4qucs) needs to be writeable!\nFor a Simulation Simulation will raise error! (most likely S4Q_workdir does not exists)").arg(msg);
+ QMessageBox::critical(nullptr,tr("Problem with SaveNetlist"),final_msg,QMessageBox::Ok);
+ }
}
void Ngspice::setSimulatorCmd(QString cmd)
diff --git a/qucs/extsimkernels/spicecompat.cpp b/qucs/extsimkernels/spicecompat.cpp
index 8f9d818e..35034a1a 100644
--- a/qucs/extsimkernels/spicecompat.cpp
+++ b/qucs/extsimkernels/spicecompat.cpp
@@ -200,7 +200,7 @@ bool spicecompat::containNodes(QStringList &tokens, QStringList &vars)
/*!
* \brief spicecompat::convertNodeNames convert node names form Qucs-notation to
- * Spice-notation (i.e. Node.Vt --> V(Node) ) and determine used simualtion.
+ * Spice-notation (i.e. Node.Vt --> V(Node) ) and determine used simulation.
* This method modifies the input list of tokens.
* \param[in/out] tokens
* \param[out] sim Used simulation.
diff --git a/qucs/extsimkernels/verilogawriter.h b/qucs/extsimkernels/verilogawriter.h
index 49a9b085..ac289b7f 100644
--- a/qucs/extsimkernels/verilogawriter.h
+++ b/qucs/extsimkernels/verilogawriter.h
@@ -37,7 +37,7 @@ namespace vacompat {
QString normalize_value(QString Value);
void convert_functions(QStringList &tokens);
QString normalize_voltage(QString &plus, QString &minus); // Exclude gnd nodes from
- QString normalize_current(QString &plus, QString &minus, bool left_side = false); // currents and volatges
+ QString normalize_current(QString &plus, QString &minus, bool left_side = false); // currents and voltages
}
class VerilogAwriter
diff --git a/qucs/extsimkernels/xspice_cmbuilder.h b/qucs/extsimkernels/xspice_cmbuilder.h
index 45a8d60d..a904556c 100644
--- a/qucs/extsimkernels/xspice_cmbuilder.h
+++ b/qucs/extsimkernels/xspice_cmbuilder.h
@@ -43,7 +43,7 @@ public:
bool needCompile();
void cleanCModelTree();
void createCModelTree(QString &output);
- void compileCMlib(QString &ouptut);
+ void compileCMlib(QString &output);
void getModIfsFileList(QStringList &files);
protected:
diff --git a/qucs/extsimkernels/xyce.cpp b/qucs/extsimkernels/xyce.cpp
index b513be5f..854192ca 100644
--- a/qucs/extsimkernels/xyce.cpp
+++ b/qucs/extsimkernels/xyce.cpp
@@ -29,7 +29,7 @@
/*!
* \brief Xyce::Xyce Class constructor
- * \param sch_ Schematic that need to be simualted with Ngspice.
+ * \param sch_ Schematic that need to be simulated with Ngspice.
* \param parent Parent object
*/
Xyce::Xyce(Schematic *sch_, QObject *parent) :
@@ -269,7 +269,7 @@ void Xyce::createNetlist(QTextStream &stream, int , QStringList &simulations,
}
/*!
- * \brief Xyce::slotSimulate Execute Xyce simualtor and perform all
+ * \brief Xyce::slotSimulate Execute Xyce simulator and perform all
* simulations from the simulationQueue list
*/
void Xyce::slotSimulate()
@@ -349,7 +349,7 @@ void Xyce::SaveNetlist(QString filename)
}
/*!
- * \brief Xyce::slotFinished Simualtor finished handler. End simulation or
+ * \brief Xyce::slotFinished Simulator finished handler. End simulation or
* execute the next simulation from queue.
*/
void Xyce::slotFinished()
diff --git a/qucs/main.cpp b/qucs/main.cpp
index 4391fc05..0618a8e0 100644
--- a/qucs/main.cpp
+++ b/qucs/main.cpp
@@ -283,8 +283,8 @@ bool saveApplSettings()
* \param msg Message
*
* The message handler is used to get control of the messages.
- * Particulary on Windows, as the messages are sent to the debugger and do not
- * show on the terminal. The handler could aslo be extended to create a log
+ * Particularly on Windows, as the messages are sent to the debugger and do not
+ * show on the terminal. The handler could also be extended to create a log
* mechanism.
*
*
@@ -675,7 +675,7 @@ void createDocData() {
char * File;
QString Name;
- int num = 0; // compoment id inside category
+ int num = 0; // component id inside category
foreach (Module *Mod, Comps) {
num += 1;
@@ -818,7 +818,9 @@ int main(int argc, char *argv[])
QucsSettings.dy = h*3/4;
// default
- QucsSettings.QucsHomeDir.setPath(QDir::homePath()+QDir::toNativeSeparators ("/.qucs"));
+ QString QucsWorkdirPath = QDir::homePath()+QDir::toNativeSeparators ("/.qucs");
+ QDir().mkpath(QucsWorkdirPath);
+ QucsSettings.QucsHomeDir.setPath(QucsWorkdirPath);
QucsSettings.QucsWorkDir.setPath(QucsSettings.QucsHomeDir.canonicalPath());
// load existing settings (if any)
@@ -943,7 +945,7 @@ int main(int argc, char *argv[])
tor.load( QString("qucs_") + lang, QucsSettings.LangDir);
a.installTranslator( &tor );
- // This seems to be neccessary on a few system to make strtod()
+ // This seems to be necessary on a few system to make strtod()
// work properly !???!
setlocale (LC_NUMERIC, "C");
diff --git a/qucs/messagedock.cpp b/qucs/messagedock.cpp
index 404d5ac5..cf6de542 100644
--- a/qucs/messagedock.cpp
+++ b/qucs/messagedock.cpp
@@ -194,7 +194,7 @@ void MessageDock::slotCursor()
}
}
- // \todo set hightlight in QucsDoc Verilog-A file?
+ // \todo set highlight in QucsDoc Verilog-A file?
// move cursor? addt line number? highliht line number? set in focus
/*
@@ -218,7 +218,7 @@ void MessageDock::slotCursor()
int pos = d->document()->findBlockByLineNumber(gotoLine-1).position();
cursor.setPosition(pos);
- // Highligt a give line
+ // Highlight a give line
QList extraSelections;
QTextEdit::ExtraSelection selection;
QColor lineColor = QColor(Qt::yellow).lighter(160);
diff --git a/qucs/misc.cpp b/qucs/misc.cpp
index ce58ba75..16a35bac 100644
--- a/qucs/misc.cpp
+++ b/qucs/misc.cpp
@@ -175,7 +175,7 @@ QString misc::StringNiceNum(double num)
if(p) {
if(!pe) pe = Buffer + strlen(Buffer);
p = pe-1;
- while(*p == '0') // looking for unneccessary zero characters
+ while(*p == '0') // looking for unnecessary zero characters
if((--p) <= Buffer) break;
if(*p != '.') p++; // no digit after decimal point ?
while( (*(p++) = *(pe++)) != 0 ) ; // overwrite zero characters
diff --git a/qucs/mouseactions.cpp b/qucs/mouseactions.cpp
index 9aba482b..9ee88b76 100644
--- a/qucs/mouseactions.cpp
+++ b/qucs/mouseactions.cpp
@@ -963,7 +963,7 @@ void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, float fX, fl
MAx1 = int(fX);
MAy1 = int(fY);
focusElement = Doc->selectElement(fX, fY, Ctrl, &No);
- isMoveEqual = false; // moving not neccessarily square
+ isMoveEqual = false; // moving not necessarily square
if(focusElement)
// print define value in hex, see element.h
@@ -1033,7 +1033,7 @@ void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, float fX, fl
QucsMain->MouseDoubleClickAction = 0;
Doc->grabKeyboard(); // no keyboard inputs during move actions
- // Remember inital scroll bar position.
+ // Remember initial scroll bar position.
MAx2 = int(((TabDiagram*)focusElement)->xAxis.limit_min);
// Update matching wire label highlighting
Doc->highlightWireLabels ();
@@ -1303,7 +1303,7 @@ void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, float, floa
default: ; // avoids compiler warnings
}
// qDebug() << " => selElem = Comp;" << Comp->Name;
- // comp it geting empty
+ // comp it getting empty
selElem = Comp;
return;
diff --git a/qucs/octave/plotTimeFFT.m b/qucs/octave/plotTimeFFT.m
index 4a8fddad..b32f4897 100644
--- a/qucs/octave/plotTimeFFT.m
+++ b/qucs/octave/plotTimeFFT.m
@@ -16,7 +16,7 @@
% Xstop X axis stop value (real).
% Linewidth Thickness of plotted line in pixels (integer).
% FTime Transient simulation FTime (real)
-% Freqmin FFT plot minimum frequeny (Hz).
+% Freqmin FFT plot minimum frequency (Hz).
% Freqmax FFT plot maximum frequency (Hz).
%
% Function written with Octave version >= 3.2.4
diff --git a/qucs/octave_window.cpp b/qucs/octave_window.cpp
index 576af41d..ddfaf164 100644
--- a/qucs/octave_window.cpp
+++ b/qucs/octave_window.cpp
@@ -91,7 +91,7 @@ bool OctaveWindow::startOctave()
QString OctavePath = QDir::toNativeSeparators(QucsSettings.OctaveExecutable);
- // Override Octave path by enviroment variable if it is set
+ // Override Octave path by environment variable if it is set
if (QucsSettings.QucsOctave.isEmpty()) Program = OctavePath;
else Program = QucsSettings.QucsOctave;
@@ -108,7 +108,7 @@ bool OctaveWindow::startOctave()
QString sep(":");
#endif
- // append process PATH, othewise Octave does not find gnuplot
+ // append process PATH, otherwise Octave does not find gnuplot
QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
env.insert("PATH", env.value("PATH") + sep + QucsSettings.BinDir );
octProcess.setProcessEnvironment(env);
diff --git a/qucs/paintings/filldialog.cpp b/qucs/paintings/filldialog.cpp
index eda70540..f092a3d5 100644
--- a/qucs/paintings/filldialog.cpp
+++ b/qucs/paintings/filldialog.cpp
@@ -37,7 +37,7 @@ FillDialog::FillDialog(const QString& _Caption, bool show, QWidget *parent)
{
setWindowTitle(_Caption);
- all = new QVBoxLayout(this); // to provide the neccessary size
+ all = new QVBoxLayout(this); // to provide the necessary size
QTabWidget *t = new QTabWidget(this);
all->addWidget(t);
diff --git a/qucs/python/qucs-py/qucs.py b/qucs/python/qucs-py/qucs.py
index 6aa099b6..545ac0c4 100644
--- a/qucs/python/qucs-py/qucs.py
+++ b/qucs/python/qucs-py/qucs.py
@@ -1,6 +1,6 @@
#!/usr/bin/python
# QUCS->Python+pylab converter ver.1.0
-# Public domain code, writter by Wojciech M. Zabolotny
+# Public domain code, written by Wojciech M. Zabolotny
# ( wzabise.pw.edu.pl ) 20.01.2009
import sys
import pylab
@@ -20,7 +20,7 @@ class qucs_data:
if l != "":
raise("This is not a qucs data file!")
# Now we should start reading dependent vars, and independent vars
- # The next line should be either dependend variable or independent variable
+ # The next line should be either dependent variable or independent variable
while True:
l=f.readline().strip()
if l=="":
diff --git a/qucs/qucs.cpp b/qucs/qucs.cpp
index fc2af63f..31e6b22a 100644
--- a/qucs/qucs.cpp
+++ b/qucs/qucs.cpp
@@ -709,7 +709,7 @@ void QucsApp::slotSetCompView (int index)
QString Name;
pInfoFunc Infos = 0;
- // if something was registered dynamicaly, get and draw icons into dock
+ // if something was registered dynamically, get and draw icons into dock
if (item == QObject::tr("verilog-a user devices")) {
compIdx = 0;
@@ -717,7 +717,7 @@ void QucsApp::slotSetCompView (int index)
while (i.hasNext()) {
i.next();
- // default icon initally matches the module name
+ // default icon initially matches the module name
//Name = i.key();
// Just need path to bitmap, do not create an object
@@ -1851,7 +1851,7 @@ void QucsApp::slotChangeView()
if (isTextDocument (w)) {
TextDoc *d = (TextDoc*)w;
Doc = (QucsDoc*)d;
- // update menu entries, etc. if neccesary
+ // update menu entries, etc. if necessary
magAll->setDisabled(true);
if(cursorLeft->isEnabled())
switchSchematicDoc (false);
@@ -2180,7 +2180,7 @@ void QucsApp::slotSimulate()
// Is called after the simulation process terminates.
void QucsApp::slotAfterSimulation(int Status, SimMessage *sim)
{
- if(Status != 0) return; // errors ocurred ?
+ if(Status != 0) return; // errors occurred ?
if(sim->ErrText->document()->lineCount() > 1) // were there warnings ?
slotShowWarnings();
@@ -2475,7 +2475,7 @@ void QucsApp::slotSelectLibComponent(QTreeWidgetItem *item)
// if the current document is a schematic activate the paste
if(!isTextDocument(Doc))
{
- // if theres not a higher level item, this is a top level item,
+ // if there's not a higher level item, this is a top level item,
// not a component item so return
if(item->parent() == 0) return;
if(item->text(1).isEmpty()) return; // return, if not a subcircuit
@@ -2844,13 +2844,13 @@ void QucsApp::updateSchNameHash(void)
// now go through the paths creating a map to all the schematic files
// found in the directories. Note that we go through the list of paths from
// first index to last index. Since keys are unique it means schematic files
- // in directories at the end of the list take precendence over those at the
+ // in directories at the end of the list take precedence over those at the
// start of the list, we should warn about shadowing of schematic files in
// this way in the future
QStringList nameFilter;
nameFilter << "*.sch";
- // clear out any existing hash table entriess
+ // clear out any existing hash table entries
schNameHash.clear();
foreach (QString qucspath, qucsPathList) {
@@ -2887,11 +2887,11 @@ void QucsApp::updateSpiceNameHash(void)
// now go through the paths creating a map to all the spice files
// found in the directories. Note that we go through the list of paths from
// first index to last index. Since keys are unique it means spice files
- // in directories at the end of the list take precendence over those at the
+ // in directories at the end of the list take precedence over those at the
// start of the list, we should warn about shadowing of spice files in
// this way in the future
- // clear out any existing hash table entriess
+ // clear out any existing hash table entries
spiceNameHash.clear();
foreach (QString qucspath, qucsPathList) {
diff --git a/qucs/qucs.h b/qucs/qucs.h
index 54994f66..8fd1abcd 100644
--- a/qucs/qucs.h
+++ b/qucs/qucs.h
@@ -311,7 +311,7 @@ private:
QToolBar *fileToolbar, *editToolbar, *viewToolbar, *workToolbar;
- // Shortcuts for scolling schematic / TextEdit
+ // Shortcuts for scrolling schematic / TextEdit
// This is rather cumbersome -> Make this with a QScrollView instead??
QShortcut *cursorUp, *cursorLeft, *cursorRight, *cursorDown;
diff --git a/qucs/qucs_actions.cpp b/qucs/qucs_actions.cpp
index 5e3b4ce3..ccbc8e45 100644
--- a/qucs/qucs_actions.cpp
+++ b/qucs/qucs_actions.cpp
@@ -1438,7 +1438,7 @@ void QucsApp::slotLoadModule()
// inform if symbol changed
// populate Module::vaComponents
// vaComponents are selected with the dialog
- // dialog should populate acording to checkboxes
+ // dialog should populate according to checkboxes
// build vaComponents QMap
// remove all previously registered modules
@@ -1464,7 +1464,7 @@ void QucsApp::slotLoadModule()
// icons of dynamically registered components ready to be dragged
}
else {
- // remove any previously registerd icons from the listview
+ // remove any previously registered icons from the listview
int foundCat = CompChoose->findText(QObject::tr("verilog-a user devices"));
if (foundCat != -1) {
CompChoose->setCurrentIndex(foundCat);
@@ -1519,7 +1519,7 @@ void QucsApp::slotBuildModule()
QString workDir = QucsSettings.QucsWorkDir.absolutePath();
- // need to cd into project to make sure output is droped there?
+ // need to cd into project to make sure output is dropped there?
// need to cd - into previous location?
QDir::setCurrent(workDir);
@@ -1537,7 +1537,7 @@ void QucsApp::slotBuildModule()
admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml");
#endif
- // admsXml emmits C++
+ // admsXml emits C++
QStringList Arguments;
Arguments << "-f" << QDir::toNativeSeparators(include.absoluteFilePath("va2cpp.makefile"))
<< QString("ADMSXML=%1").arg(admsXml)
diff --git a/qucs/qucs_init.cpp b/qucs/qucs_init.cpp
index f834eebe..f7c50b38 100644
--- a/qucs/qucs_init.cpp
+++ b/qucs/qucs_init.cpp
@@ -1045,7 +1045,7 @@ void QucsApp::slotViewStatusBar(bool toggle)
}
// ----------------------------------------------------------
-// turn Brwose Dock Window on or off
+// turn Browse Dock Window on or off
void QucsApp::slotViewBrowseDock(bool toggle)
{
dock->setVisible(toggle);
diff --git a/qucs/schematic.cpp b/qucs/schematic.cpp
index 449461ee..eda92038 100644
--- a/qucs/schematic.cpp
+++ b/qucs/schematic.cpp
@@ -1900,7 +1900,7 @@ void Schematic::contentsWheelEvent(QWheelEvent *Event)
}
// ...................................................................
else if(Event->modifiers() & Qt::ControlModifier) { // use mouse wheel to zoom ?
- // zoom factor scaled according to the wheel delta, to accomodate
+ // zoom factor scaled according to the wheel delta, to accommodate
// values different from 60 (slower or faster zoom)
int delta = Event->angleDelta().y();
float Scaling = pow(1.1, delta/60.0);
diff --git a/qucs/schematic_file.cpp b/qucs/schematic_file.cpp
index 08399345..74e7c549 100644
--- a/qucs/schematic_file.cpp
+++ b/qucs/schematic_file.cpp
@@ -983,7 +983,7 @@ QString Schematic::createSymbolUndoString(char Op)
}
// -------------------------------------------------------------
-// Is quite similiar to "loadDocument()" but with less error checking.
+// Is quite similar to "loadDocument()" but with less error checking.
// Used for "undo" function.
bool Schematic::rebuild(QString *s)
{
@@ -1801,7 +1801,7 @@ bool Schematic::createSubNetlist(QTextStream *stream, int& countInit,
AbstractSpiceKernel *kern = new AbstractSpiceKernel(this);
QStringList err_lst;
if (!kern->checkSchematic(err_lst)) {
- QString s = QString("Subcircuit %1 conatins SPICE-incompatible components.\n"
+ QString s = QString("Subcircuit %1 contains SPICE-incompatible components.\n"
"Check these components: %2 \n")
.arg(this->DocName).arg(err_lst.join("; "));
ErrText->insertPlainText(s);
diff --git a/qucs/spicecomponents/CMakeLists.txt b/qucs/spicecomponents/CMakeLists.txt
index 56e0cd05..29b6ef33 100644
--- a/qucs/spicecomponents/CMakeLists.txt
+++ b/qucs/spicecomponents/CMakeLists.txt
@@ -1,4 +1,4 @@
-# qucs/componenets library
+# qucs/components library
INCLUDE_DIRECTORIES( ${CMAKE_SOURCE_DIR}
${CMAKE_CURRENT_SOURCE_DIR} )
diff --git a/qucs/symbolwidget.cpp b/qucs/symbolwidget.cpp
index 297a2f61..74ece4ec 100644
--- a/qucs/symbolwidget.cpp
+++ b/qucs/symbolwidget.cpp
@@ -374,7 +374,7 @@ int SymbolWidget::createStandardSymbol(const QString& Lib_, const QString& Comp_
* \param SymbolString
* \param Lib_
* \param Comp_
- * \return the number of painting elements or a negative nuber if error
+ * \return the number of painting elements or a negative number if error
*/
int SymbolWidget::setSymbol( QString& SymbolString,
const QString& Lib_, const QString& Comp_)
diff --git a/qucs/textdoc.cpp b/qucs/textdoc.cpp
index 355406a8..cb599bd8 100644
--- a/qucs/textdoc.cpp
+++ b/qucs/textdoc.cpp
@@ -95,7 +95,7 @@ TextDoc::~TextDoc()
/*!
* \brief TextDoc::setLanguage(const QString&)
* \param FileName Text document file name
- * Extract the file name suffix and assing a language_type to it.
+ * Extract the file name suffix and assign a language_type to it.
*/
void TextDoc::setLanguage (const QString& FileName)
{
@@ -116,7 +116,7 @@ void TextDoc::setLanguage (const QString& FileName)
/*!
* \brief TextDoc::setLanguage(int)
* \param lang is a language_type
- * Assing value to text document object language variable
+ * Assign value to text document object language variable
*/
void TextDoc::setLanguage (int lang)
{
diff --git a/qucs/viewpainter.h b/qucs/viewpainter.h
index 7fcaa39a..2bbd55ef 100644
--- a/qucs/viewpainter.h
+++ b/qucs/viewpainter.h
@@ -24,9 +24,9 @@ class QColor;
#define TO_INT(f) (f > 0.0 ? int(f + 0.5) : int(f - 0.5))
-/* This class is neccessary because scaled fonts looks very ungly.
+/* This class is necessary because scaled fonts looks very ugly.
Avoiding this is unfortunately not easy.
- This class scales the font point size instead of the font glyphes.
+ This class scales the font point size instead of the font glyphs.
But this has the disadvantage, that the text size does not increase
equally with the rest of the drawing. We therefore must compute
some thing anew each time the paint function is called. The class
diff --git a/translations/CMakeLists.txt b/translations/CMakeLists.txt
index d1415bde..337a9474 100644
--- a/translations/CMakeLists.txt
+++ b/translations/CMakeLists.txt
@@ -32,7 +32,7 @@ ENDIF (UPDATE_TRANSLATIONS)
#FILE(GLOB QtTRANSLATIONS qtgeneric_*.ts)
#
-# install tranlations
+# install translations
INSTALL( FILES ${QM_FILES} DESTINATION share/${QUCS_NAME}/lang)
# prevent the generated files from being deleted during make clean
diff --git a/qucs/components/component.cpp b/qucs/components/component.cpp
index 94561f0e..25b8595a 100644
--- a/qucs/components/component.cpp
+++ b/qucs/components/component.cpp
@@ -770,14 +770,14 @@ QString Component::getSpiceModel()
QString Component::getNgspiceBeforeSim(QString sim, int lvl)
{
- Q_UNUSED(sim); // To supress warning
+ Q_UNUSED(sim); // To suppress warning
Q_UNUSED(lvl);
return QString("");
}
QString Component::getNgspiceAfterSim(QString sim, int lvl)
{
- Q_UNUSED(sim); // To supress warning
+ Q_UNUSED(sim); // To suppress warning
Q_UNUSED(lvl);
return QString("");
}
@@ -939,7 +939,7 @@ bool Component::load(const QString& _s)
n = s.section(' ',8,8); // rotated
tmp = n.toInt(&ok);
if(!ok) return false;
- if(rotated > tmp) // neccessary because of historical flaw in ...
+ if(rotated > tmp) // necessary because of historical flaw in ...
tmp += 4; // ... components like "volt_dc"
for(int z=rotated; zsetLayout(all);
all->setContentsMargins(1,1,1,1);
QGridLayout *gp1;
@@ -471,7 +471,7 @@ ComponentDialog::ComponentDialog(Component *c, Schematic *d)
}
- /// \todo add key up/down brose and select prop
+ /// \todo add key up/down browse and select prop
connect(prop, SIGNAL(itemClicked(QTableWidgetItem*)),
SLOT(slotSelectProperty(QTableWidgetItem*)));
}
@@ -600,7 +600,7 @@ void ComponentDialog::slotSelectProperty(QTableWidgetItem *item)
}
/// \todo enable edit of description anyway...
/// empy or "-" (no comment from verilog-a)
if(desc.isEmpty()) {
// show two line edit fields (name and value)
ButtAdd->setEnabled(true);
@@ -1156,7 +1156,7 @@ void ComponentDialog::slotEditFile()
Add description if missing.
Is called if the add button is pressed. This is only possible for some
properties.
- If desc is empy, ButtAdd is enabled, this slot handles if it is clicked.
+ If desc is empty, ButtAdd is enabled, this slot handles if it is clicked.
Used with: Equation, ?
Original behavior for an Equation block
@@ -1220,7 +1220,7 @@ void ComponentDialog::slotButtAdd()
/*!
Is called if the remove button is pressed. This is only possible for
some properties.
- If desc is empy, ButtRem is enabled, this slot handles if it is clicked.
+ If desc is empty, ButtRem is enabled, this slot handles if it is clicked.
Used with: Equations, ?
*/
void ComponentDialog::slotButtRem()
@@ -600,7 +600,7 @@ void ComponentDialog::slotSelectProperty(QTableWidgetItem *item)
}
/// \todo enable edit of description anyway...
- /// empy or "-" (no comment from verilog-a)
+ /// empty or "-" (no comment from verilog-a)
if(desc.isEmpty()) {
// show two line edit fields (name and value)